@@ -1,7 +1,33 @@
 from typing import Any
 
 
-class BidirectionalDict(dict):
+class BaseDict(dict):
+    """Dictionary with pretty :py:func:`__repr__` output.
+
+    Base class that all other dictionaries in this file inherit from. :py:func:`__repr__` is
+    replaced with ``<{class_name} {dictionary data}>`` output style for implicit inferences.
+
+    Example:
+
+        .. code-block:: python
+
+            from toolbox.collections.mapping import BaseDict
+
+            class NewDict(BaseDict):
+                '''New dictionary example.'''
+
+            d = NewDict({"hello": "world"})
+            print(d) # >>> <NewDict {'hello': 'world'}>
+    """
+
+    def __repr__(self):
+        return "<{} {}>".format(
+            self.__class__.__name__,
+            super(BaseDict, self).__repr__(),
+        )
+
+
+class BidirectionalDict(BaseDict):
     """Dictionary with two-way capabilities.
 
     Example:
@@ -11,7 +37,7 @@ class BidirectionalDict(dict):
             from toolbox.collections.mapping import BidirectionalDict
 
             d = BidirectionalDict({"hello": "world"})
-            print(d) # >>> {'hello': 'world', 'world': 'hello'}
+            print(d) # >>> <BidirectionalDict {'hello': 'world', 'world': 'hello'}>
     """
 
     def __init__(self, dictionary: dict = {}, **kwargs) -> dict:
@@ -29,7 +55,7 @@ class BidirectionalDict(dict):
         super(BidirectionalDict, self).__setitem__(value, key)
 
 
-class ObjectDict(dict):
+class ObjectDict(BaseDict):
     """Dictionary that can be accessed as though it was an object.
 
     Example:
@@ -39,6 +65,8 @@ class ObjectDict(dict):
             from toolbox.collections.mapping import ObjectDict
 
             d = ObjectDict({"hello": "world"})
+            print(d) # >>> <ObjectDict {'hello': 'world'}>
+
             print(d.hello) # >>> 'world'
     """
 
@@ -46,7 +74,7 @@ class ObjectDict(dict):
         return self.__getitem__(key)
 
 
-class OverloadedDict(dict):
+class OverloadedDict(BaseDict):
     """Dictionary that can be added or subtracted.
 
     Example:
@@ -56,11 +84,13 @@ class OverloadedDict(dict):
             from toolbox.collections.mapping import OverloadedDict
 
             d1 = OverloadedDict({"hello": "world"})
-            d2 = OverloadedDict({"ola": "mundo"})
+            d2 = {"ola": "mundo"}
+
             d1 += d2
-            print(d1) # >>> {'hello': 'world', 'ola': 'mundo'}
+            print(d1) # >>> <OverloadedDict {'hello': 'world', 'ola': 'mundo'}>
+
             d1 -= d2
-            print(d1) # >>> {'hello': 'world'}
+            print(d1) # >>> <OverloadedDict {'hello': 'world'}>
     """
 
     def __add__(self, other: dict) -> dict:
@@ -80,7 +110,7 @@ class OverloadedDict(dict):
         return self
 
 
-class UnderscoreAccessDict(dict):
+class UnderscoreAccessDict(BaseDict):
     """Dictionary that doesn't distinct keys with empty spaces and underscores.
 
     Example:
@@ -90,7 +120,9 @@ class UnderscoreAccessDict(dict):
             from toolbox.collections.mapping import UnderscoreAccessDict
 
             d = UnderscoreAccessDict({"hello world": "ola mundo"})
-            d['hello_world'] # >>> 'ola mundo'
+            print(d) # >>> <UnderscoreAccessDict {'hello world': 'ola mundo'}>
+
+            print(d['hello_world']) # >>> 'ola mundo'
     """
 
     def __getitem__(self, key: Any) -> Any:
@@ -102,3 +134,22 @@ class UnderscoreAccessDict(dict):
             return super(UnderscoreAccessDict, self).__getitem__(wtu)
 
         return super(UnderscoreAccessDict, self).__getitem__(key)
+
+
+class FrozenDict(BaseDict):
+    """Dictionary that is frozen.
+
+    .. code-block:: python
+
+        from toolbox.collections.mapping import FrozenDict
+
+        d = FrozenDict({"hello": "world"})
+        print(d) # >>> <FrozenDict {'hello': 'world'}>
+
+        d['ola'] = 'mundo'
+        # >>> KeyError: 'Cannot set key and value because this is a frozen dictionary.'
+    """
+
+    def __setitem__(self, key, value):
+        err = "Cannot set key and value because this is a frozen dictionary."
+        raise KeyError(err)
